@@ -159,6 +159,9 @@ typedef struct RE_ERROR RE_ERROR;
 typedef struct RE_FIBER RE_FIBER;
 typedef struct RE_FIBER_LIST RE_FIBER_LIST;
 typedef struct RE_FIBER_POOL RE_FIBER_POOL;
+typedef struct RE_FAST_EXEC_POSITION RE_FAST_EXEC_POSITION;
+typedef struct RE_FAST_EXEC_POSITION_LIST RE_FAST_EXEC_POSITION_LIST;
+typedef struct RE_FAST_EXEC_POSITION_POOL RE_FAST_EXEC_POSITION_POOL;
 
 typedef struct YR_AC_STATE YR_AC_STATE;
 typedef struct YR_AC_AUTOMATON YR_AC_AUTOMATON;
@@ -394,12 +397,21 @@ struct RE_AST
 #pragma warning(disable : 4200)
 #endif
 
+// The RE structure is embedded in the YARA's VM instruction flow, which
+// means that its alignment is not guaranteed. For this reason the it must
+// be a "packed" structure, in order to prevent alignment issues in platforms
+// with strict alignment constraints.
+#pragma pack(push)
+#pragma pack(1)
+
 struct RE
 {
   uint32_t flags;
   uint8_t code[0];
 };
 
+#pragma pack(pop)
+
 #ifdef _MSC_VER
 #pragma warning(pop)
 #endif
@@ -433,6 +445,19 @@ struct RE_FIBER_POOL
   RE_FIBER_LIST fibers;
 };
 
+struct RE_FAST_EXEC_POSITION
+{
+  int round;
+  const uint8_t* input;
+  RE_FAST_EXEC_POSITION* prev;
+  RE_FAST_EXEC_POSITION* next;
+};
+
+struct RE_FAST_EXEC_POSITION_POOL
+{
+  RE_FAST_EXEC_POSITION* head;
+};
+
 struct YR_MODIFIER
 {
   int32_t flags;
@@ -470,6 +495,9 @@ struct YR_MATCH
 
   // True if this is match for a private string.
   bool is_private;
+
+  // Set to the xor key if this is an xor string.
+  uint8_t xor_key;
 };
 
 struct YR_AC_STATE
@@ -760,6 +788,9 @@ struct YR_SCAN_CONTEXT
   // Fiber pool used by yr_re_exec.
   RE_FIBER_POOL re_fiber_pool;
 
+  // Pool used by yr_re_fast_exec.
+  RE_FAST_EXEC_POSITION_POOL re_fast_exec_position_pool;
+
   // A bitmap with one bit per rule, bit N is set when the rule with index N
   // has matched.
   YR_BITMASK* rule_matches_flags;
@@ -803,8 +834,8 @@ union YR_VALUE
 
 struct YR_VALUE_STACK
 {
-  int32_t sp;
-  int32_t capacity;
+  uint32_t sp;
+  uint32_t capacity;
   YR_VALUE* items;
 };
 
@@ -958,9 +989,24 @@ struct YR_INT_ENUM_ITERATOR
   int64_t items[1];
 };
 
+struct YR_STRING_SET_ITERATOR
+{
+  int64_t count;
+  int64_t index;
+  YR_STRING* strings[1];
+};
+
+struct YR_TEXT_STRING_SET_ITERATOR
+{
+  int64_t count;
+  int64_t index;
+  SIZED_STRING* strings[1];
+};
+
 struct YR_ITERATOR
 {
-  YR_ITERATOR_NEXT_FUNC next;
+  // Index of the next function within the iter_next_func_table global array.
+  uint8_t next_func_idx;
 
   union
   {
@@ -968,6 +1014,8 @@ struct YR_ITERATOR
     struct YR_DICT_ITERATOR dict_it;
     struct YR_INT_RANGE_ITERATOR int_range_it;
     struct YR_INT_ENUM_ITERATOR int_enum_it;
+    struct YR_STRING_SET_ITERATOR string_set_it;
+    struct YR_TEXT_STRING_SET_ITERATOR text_string_set_it;
   };
 };
 
