@@ -55,6 +55,7 @@ typedef struct _CALLBACK_ARGS
 
   int forward_matches;
   int full_word;
+  int xor_key;
 
 } CALLBACK_ARGS;
 
@@ -62,7 +63,8 @@ static int _yr_scan_xor_compare(
     const uint8_t* data,
     size_t data_size,
     uint8_t* string,
-    size_t string_length)
+    size_t string_length,
+    uint8_t* xor_key)
 {
   int result = 0;
   const uint8_t* s1 = data;
@@ -94,6 +96,9 @@ _exit:;
       string_length,
       result);
 
+  if (result > 0)
+    *xor_key = k;
+
   return result;
 }
 
@@ -101,8 +106,10 @@ static int _yr_scan_xor_wcompare(
     const uint8_t* data,
     size_t data_size,
     uint8_t* string,
-    size_t string_length)
+    size_t string_length,
+    uint8_t* xor_key)
 {
+  int result = 0;
   const uint8_t* s1 = data;
   const uint8_t* s2 = string;
   uint8_t k = 0;
@@ -124,7 +131,12 @@ static int _yr_scan_xor_wcompare(
     i++;
   }
 
-  return (int) ((i == string_length) ? i * 2 : 0);
+  result = (int) ((i == string_length) ? i * 2 : 0);
+
+  if (result > 0)
+    *xor_key = k;
+
+  return result;
 }
 
 static int _yr_scan_compare(
@@ -397,7 +409,8 @@ static int _yr_scan_verify_chained_string_match(
     const uint8_t* match_data,
     uint64_t match_base,
     uint64_t match_offset,
-    int32_t match_length)
+    int32_t match_length,
+    uint8_t xor_key)
 {
   YR_DEBUG_FPRINTF(
       2,
@@ -584,6 +597,7 @@ static int _yr_scan_verify_chained_string_match(
       new_match->prev = NULL;
       new_match->next = NULL;
       new_match->is_private = STRING_IS_PRIVATE(matching_string);
+      new_match->xor_key = xor_key;
 
       // A copy of the matching data is written to the matches_arena, the
       // amount of data copies is limited by YR_CONFIG_MAX_MATCH_DATA.
@@ -687,7 +701,8 @@ static int _yr_scan_match_callback(
         match_data,
         callback_args->data_base,
         match_offset,
-        match_length);
+        match_length,
+        callback_args->xor_key);
   }
   else
   {
@@ -733,6 +748,7 @@ static int _yr_scan_match_callback(
       new_match->prev = NULL;
       new_match->next = NULL;
       new_match->is_private = STRING_IS_PRIVATE(string);
+      new_match->xor_key = callback_args->xor_key;
 
       FAIL_ON_ERROR(_yr_scan_add_match_to_list(
           new_match,
@@ -843,6 +859,8 @@ static int _yr_scan_verify_re_match(
   callback_args.data_base = data_base;
   callback_args.forward_matches = forward_matches;
   callback_args.full_word = STRING_IS_FULL_WORD(ac_match->string);
+  // xor modifier is not valid for RE but set it so we don't leak stack values.
+  callback_args.xor_key = 0;
 
   if (ac_match->backward_code != NULL)
   {
@@ -886,6 +904,7 @@ static int _yr_scan_verify_literal_match(
 
   int flags = 0;
   int forward_matches = 0;
+  uint8_t xor_key = 0;
 
   CALLBACK_ARGS callback_args;
   YR_STRING* string = ac_match->string;
@@ -893,6 +912,28 @@ static int _yr_scan_verify_literal_match(
   if (STRING_FITS_IN_ATOM(string))
   {
     forward_matches = ac_match->backtrack;
+    if (STRING_IS_XOR(string))
+    {
+      if (STRING_IS_WIDE(string))
+      {
+        _yr_scan_xor_wcompare(
+            data + offset,
+            data_size - offset,
+            string->string,
+            string->length,
+            &xor_key);
+      }
+
+      if (STRING_IS_ASCII(string))
+      {
+        _yr_scan_xor_compare(
+            data + offset,
+            data_size - offset,
+            string->string,
+            string->length,
+            &xor_key);
+      }
+    }
   }
   else if (STRING_IS_NO_CASE(string))
   {
@@ -927,13 +968,21 @@ static int _yr_scan_verify_literal_match(
       if (STRING_IS_WIDE(string))
       {
         forward_matches = _yr_scan_xor_wcompare(
-            data + offset, data_size - offset, string->string, string->length);
+            data + offset,
+            data_size - offset,
+            string->string,
+            string->length,
+            &xor_key);
       }
 
       if (forward_matches == 0)
       {
         forward_matches = _yr_scan_xor_compare(
-            data + offset, data_size - offset, string->string, string->length);
+            data + offset,
+            data_size - offset,
+            string->string,
+            string->length,
+            &xor_key);
       }
     }
   }
@@ -954,6 +1003,7 @@ static int _yr_scan_verify_literal_match(
   callback_args.data_base = data_base;
   callback_args.forward_matches = forward_matches;
   callback_args.full_word = STRING_IS_FULL_WORD(string);
+  callback_args.xor_key = xor_key;
 
   FAIL_ON_ERROR(
       _yr_scan_match_callback(data + offset, 0, flags, &callback_args));
