@@ -37,6 +37,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <yara/object.h>
 #include <yara/proc.h>
 #include <yara/scanner.h>
+#include <yara/strutils.h>
 #include <yara/types.h>
 
 #include "exception.h"
@@ -241,6 +242,16 @@ YR_API int yr_scanner_create(YR_RULES* rules, YR_SCANNER** scanner)
   new_scanner->unconfirmed_matches = (YR_MATCHES*) yr_calloc(
       rules->num_strings, sizeof(YR_MATCHES));
 
+  if (new_scanner->rule_matches_flags == NULL ||
+      new_scanner->ns_unsatisfied_flags == NULL ||
+      new_scanner->strings_temp_disabled == NULL ||
+      new_scanner->matches == NULL ||  //
+      new_scanner->unconfirmed_matches == NULL)
+  {
+    yr_scanner_destroy(new_scanner);
+    return ERROR_INSUFFICIENT_MEMORY;
+  }
+
 #ifdef YR_PROFILING_ENABLED
   new_scanner->profiling_info = yr_calloc(
       rules->num_rules, sizeof(YR_PROFILING_INFO));
@@ -287,16 +298,22 @@ YR_API void yr_scanner_destroy(YR_SCANNER* scanner)
 {
   YR_DEBUG_FPRINTF(2, stderr, "- %s() {} \n", __FUNCTION__);
 
-  RE_FIBER* fiber;
-  RE_FIBER* next_fiber;
-
-  fiber = scanner->re_fiber_pool.fibers.head;
+  RE_FIBER* fiber = scanner->re_fiber_pool.fibers.head;
 
   while (fiber != NULL)
   {
-    next_fiber = fiber->next;
+    RE_FIBER* next = fiber->next;
     yr_free(fiber);
-    fiber = next_fiber;
+    fiber = next;
+  }
+
+  RE_FAST_EXEC_POSITION* position = scanner->re_fast_exec_position_pool.head;
+
+  while (position != NULL)
+  {
+    RE_FAST_EXEC_POSITION* next = position->next;
+    yr_free(position);
+    position = next;
   }
 
   if (scanner->objects_table != NULL)
@@ -444,7 +461,7 @@ YR_API int yr_scanner_scan_mem_blocks(
     uint32_t max_match_data;
 
     FAIL_ON_ERROR(
-        yr_get_configuration(YR_CONFIG_MAX_MATCH_DATA, &max_match_data));
+        yr_get_configuration_uint32(YR_CONFIG_MAX_MATCH_DATA, &max_match_data));
 
     result = yr_notebook_create(
         1024 * (sizeof(YR_MATCH) + max_match_data), &scanner->matches_notebook);
